@@ -6,24 +6,22 @@ import (
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/lipgloss"
 	"io"
-	"strings"
 )
 
 var (
 	itemStyle         = lipgloss.NewStyle().PaddingLeft(4)
-	currentItemStyle  = lipgloss.NewStyle().PaddingLeft(2).Foreground(lipgloss.Color("170"))
+	currentItemStyle  = lipgloss.NewStyle().PaddingLeft(2).Foreground(lipgloss.Color("170")).Width(150)
 	selectedItemStyle = lipgloss.NewStyle().PaddingLeft(2).Foreground(lipgloss.Color("#00ff00"))
 	paginationStyle   = list.DefaultStyles().PaginationStyle.PaddingLeft(4)
 	helpStyle         = list.DefaultStyles().HelpStyle.PaddingLeft(4).PaddingBottom(1)
 )
 
 type HistoryItem struct {
-	Command       string
+	Command string
 }
 
 func NewHistoryItem(historyEntry string) *HistoryItem {
-	historyParts := strings.Split(historyEntry, ";")
-	return &HistoryItem{Command: historyParts[len(historyParts)-1]}
+	return &HistoryItem{Command: historyEntry}
 }
 
 func (h HistoryItem) FilterValue() string {
@@ -54,8 +52,9 @@ func (h HistoryItemDelegate) Render(w io.Writer, m list.Model, index int, listIt
 
 	fn := itemStyle.Render
 	if index == m.Index() {
-		fn = func(s string) string {
-			return currentItemStyle.Render("> " + s)
+		fn = func(s ...string) string {
+			var str = []string{"> "}
+			return currentItemStyle.Render(append(str, s...)...)
 		}
 	}
 
