@@ -9,25 +9,22 @@ type SelectionManager struct {
 }
 
 func (r *SelectionManager) Add(item *HistoryItem) {
+	if r.Contains(item) {
+		return
+	}
 	r.items = append(r.items, item)
 }
 
 func (r *SelectionManager) Remove(item *HistoryItem) {
-	for i, v := range r.items {
-		if v == item {
-			r.items = append(r.items[:i], r.items[i+1:]...)
-			return
-		}
+	index := r.IndexOf(item)
+	if index == -1 {
+		return
 	}
+	r.items = append(r.items[:index], r.items[index+1:]...)
 }
 
 func (r *SelectionManager) Contains(item *HistoryItem) bool {
-	for _, v := range r.items {
-		if v == item {
-			return true
-		}
-	}
-	return false
+	return r.IndexOf(item) != -1
 }
 
 func (r *SelectionManager) IndexOf(item *HistoryItem) int {
